## 国际化

ZKTeco 组件内部默认使用中文，若希望使用其他语言，则需要进行多语言设置。以英文为例，在 main.js 中：

```javascript
import Vue from 'vue'
import theme from 'src/theme'
import locale from 'src/theme/locale/lang/en'

Vue.use(theme, { locale })
```

或

```javascript
// 按需引入 ZKTecoFE
import Vue from 'vue'
import { Button, Select } from 'src/theme'
import lang from 'src/theme/locale/lang/en'
import locale from 'src/theme/locale'

// 设置语言
locale.use(lang)

// 引入组件
Vue.component(Button.name, Button)
Vue.component(Select.name, Select)
```

如果使用其它语言，默认情况下中文语言包依旧是被引入的，可以使用 webpack 的 IgnorePlugin 忽略掉它以减少打包后的文件体积。

**webpack.config.js**
```javascript
{
  plugins: [
    new webpack.IgnorePlugin(/src/theme\/lib\/locale\/lang\/zh-CN/)
  ]
}
```

目前 ZKTeco 内置了以下语言：
<ul class="language-list">
  <li>汉语（zh-CN）</li>
  <li>英语（en）</li>
  <li>德语（de）</li>
  <li>葡萄牙语（pt）</li>
</ul>
 
如果你需要使用其他的语言，欢迎贡献 PR：只需在 [src/theme/locale/lang]() 添加一个语言配置文件即可。
