
## NavMenu 导航菜单

为网站提供导航功能的菜单。

### 顶栏

适用广泛的基础用法。

> demo


```html
<zk-menu theme="dark" default-active="1" class="zk-menu-demo" mode="horizontal" @select="handleSelect">
  <zk-menu-item index="1">处理中心</zk-menu-item>
  <zk-submenu index="2">
    <template slot="title">我的工作台</template>
    <zk-menu-item index="2-1">选项1</zk-menu-item>
    <zk-menu-item index="2-2">选项2</zk-menu-item>
    <zk-menu-item index="2-3">选项3</zk-menu-item>
  </zk-submenu>
  <zk-menu-item index="3">订单管理</zk-menu-item>
</zk-menu>
<div class="line"></div>
<zk-menu default-active="1" class="zk-menu-demo" mode="horizontal" @select="handleSelect">
  <zk-menu-item index="1">处理中心</zk-menu-item>
  <zk-submenu index="2">
    <template slot="title">我的工作台</template>
    <zk-menu-item index="2-1">选项1</zk-menu-item>
    <zk-menu-item index="2-2">选项2</zk-menu-item>
    <zk-menu-item index="2-3">选项3</zk-menu-item>
  </zk-submenu>
  <zk-menu-item index="3">订单管理</zk-menu-item>
</zk-menu>

<script>
  export default {
    methods: {
      handleSelect(key, keyPath) {
        console.log(key, keyPath);
      }
    }
  }
</script>
```



### 侧栏

垂直菜单，可内嵌子菜单。

> demo


```html
<zk-row class="tac">
  <zk-col :span="8">
    <h5>带 icon</h5>
    <zk-menu default-active="2" class="zk-menu-vertical-demo" @open="handleOpen" @close="handleClose">
      <zk-submenu index="1">
        <template slot="title"><i class="zk-icon-message"></i>导航一</template>
        <zk-menu-item-group title="分组一">
          <zk-menu-item index="1-1">选项1</zk-menu-item>
          <zk-menu-item index="1-2">选项2</zk-menu-item>
        </zk-menu-item-group>
        <zk-menu-item-group title="分组2">
          <zk-menu-item index="1-3">选项3</zk-menu-item>
        </zk-menu-item-group>
      </zk-submenu>
      <zk-menu-item index="2"><i class="zk-icon-menu"></i>导航二</zk-menu-item>
      <zk-menu-item index="3"><i class="zk-icon-setting"></i>导航三</zk-menu-item>
    </zk-menu>
  </zk-col>
  <zk-col :span="8">
    <h5>不带 icon</h5>
    <zk-menu default-active="2" class="zk-menu-vertical-demo" @open="handleOpen" @close="handleClose" theme="dark">
      <zk-submenu index="1">
        <template slot="title">导航一</template>
        <zk-menu-item-group title="分组一">
          <zk-menu-item index="1-1">选项1</zk-menu-item>
          <zk-menu-item index="1-2">选项2</zk-menu-item>
        </zk-menu-item-group>
        <zk-menu-item-group title="分组2">
          <zk-menu-item index="1-3">选项3</zk-menu-item>
        </zk-menu-item-group>
      </zk-submenu>
      <zk-menu-item index="2">导航二</zk-menu-item>
      <zk-menu-item index="3">导航三</zk-menu-item>
    </zk-menu>
  </zk-col>
  <zk-col :span="8">
    <h5>分组</h5>
    <zk-menu mode="vertical" default-active="1" class="zk-menu-vertical-demo">
      <zk-menu-item-group title="分组一">
        <zk-menu-item index="1"><i class="zk-icon-message"></i>导航一</zk-menu-item>
        <zk-menu-item index="2"><i class="zk-icon-message"></i>导航二</zk-menu-item>
      </zk-menu-item-group>
      <zk-menu-item-group title="分组二">
        <zk-menu-item index="3"><i class="zk-icon-message"></i>导航三</zk-menu-item>
        <zk-menu-item index="4"><i class="zk-icon-message"></i>导航四</zk-menu-item>
        <!-- <zk-submenu index="5">
          <template slot="title">导航五</template>
          <zk-menu-item-group title="分组一">
            <zk-menu-item index="5-1">选项1</zk-menu-item>
            <zk-menu-item index="5-2">选项2</zk-menu-item>
          </zk-menu-item-group>
          <zk-menu-item-group title="分组二">
            <zk-menu-item index="5-3">选项3</zk-menu-item>
          </zk-menu-item-group>
        </zk-submenu> -->
      </zk-menu-item-group>
    </zk-menu>
  </zk-col>
</zk-row>

<script>
  export default {
    methods: {
      handleOpen(key, keyPath) {
        console.log(key, keyPath);
      },
      handleClose(key, keyPath) {
        console.log(key, keyPath);
      }
    }
  }
</script>
```



### Menu Attribute
| 参数      | 说明    | 类型      | 可选值       | 默认值   |
|---------- |-------- |---------- |-------------  |-------- |
| mode     | 模式   | string  |   horizontal,vertical   | vertical |
| theme     | 主题色   | string    | light,dark | light |
| default-active | 当前激活菜单的 index | string    | — | — |
| default-openeds | 当前打开的submenu的 key 数组 | Array    | — | — |
| unique-opened  | 是否只保持一个子菜单的展开 | boolean   | — | false   |
| menu-trigger  | 子菜单打开的触发方式(只在 mode 为 horizontal 时有效) | string   | — | hover   |
| router  | 是否使用 vue-router 的模式，启用该模式会在激活导航时以 index 作为 path 进行路由跳转 | boolean   | — | false   |

### Menu Events
| 事件名称      | 说明    | 回调参数      |
|---------- |-------- |---------- |
| select  | 菜单激活回调 | index: 选中菜单项的 indexPath: 选中菜单项的 index path  |
| open  | SubMenu 展开的回调 | index: 打开的 subMenu 的 index， indexPath: 打开的 subMenu 的 index path  |
| close  | SubMenu 收起的回调 | index: 收起的 subMenu 的 index， indexPath: 收起的 subMenu 的 index path  |

### SubMenu Attribute
| 参数      | 说明    | 类型      | 可选值       | 默认值   |
|---------- |-------- |---------- |-------------  |-------- |
| index     | 唯一标志   | string  | — | — |

### Menu-Item Attribute
| 参数      | 说明    | 类型      | 可选值       | 默认值   |
|---------- |-------- |---------- |-------------  |-------- |
| index     | 唯一标志   | string  | — | — |
| route     | Vue Router 路径对象 | Object | — | — |

### Menu-Group Attribute
| 参数      | 说明    | 类型      | 可选值       | 默认值   |
|---------- |-------- |---------- |-------------  |-------- |
| title     | 分组标题   | string  | — | — |
